@@ -4,7 +4,7 @@ import collections
 import dataclasses
 import os
 from pathlib import Path
-from typing import Any, Callable, Iterator, Mapping, MutableMapping, cast
+from typing import Any, Callable, ClassVar, Iterator, Mapping, MutableMapping, cast
 
 import platformdirs
 import rich.theme
@@ -55,6 +55,13 @@ def ensure_boolean(val: Any) -> bool:
     return bool(val) and val.lower() not in ("false", "no", "0")
 
 
+def split_by_comma(val: list[str] | str) -> list[str]:
+    """Split a string value by comma"""
+    if isinstance(val, str):
+        return [v.strip() for v in val.split(",")]
+    return val
+
+
 DEFAULT_PYPI_INDEX = "https://pypi.org/simple"
 
 
@@ -87,7 +94,7 @@ class ConfigItem:
 class Config(MutableMapping[str, str]):
     """A dict-like object for configuration key and values"""
 
-    _config_map: dict[str, ConfigItem] = {
+    _config_map: ClassVar[dict[str, ConfigItem]] = {
         "cache_dir": ConfigItem(
             "The root directory of cached files",
             platformdirs.user_cache_dir("pdm"),
@@ -155,6 +162,9 @@ class Config(MutableMapping[str, str]):
             "`symlink` or `pth` to create links to the cached installation",
             "symlink",
         ),
+        "python.providers": ConfigItem(
+            "List of python provider names for findpython", default=[], coerce=split_by_comma
+        ),
         "python.use_pyenv": ConfigItem("Use the pyenv interpreter", True, coerce=ensure_boolean),
         "python.use_venv": ConfigItem(
             "Use virtual environments when available", True, env_var="PDM_USE_VENV", coerce=ensure_boolean
@@ -260,7 +270,7 @@ class Config(MutableMapping[str, str]):
 
     def iter_sources(self) -> Iterator[RepositoryConfig]:
         for name, data in self._data.items():
-            if name.startswith(f"{SOURCE}.") and name not in self._config_map:
+            if name.startswith(f"{SOURCE}.") and name not in self._config_map and data:
                 yield RepositoryConfig(**data, name=name[len(SOURCE) + 1 :], config_prefix=SOURCE)
 
     def _save_config(self) -> None:
